==> abe-cli-0.2.70.tgz: package/src/server/public/scripts/modules/EditorJson.js <==
import Nanoajax from 'nanoajax'
import qs from 'qs'
import {Promise} from 'es6-promise'
import on from 'on'
let singleton = Symbol()
let singletonEnforcer = Symbol()

export default class Json {

  constructor(enforcer) {
    this._data = json
    this._ajax = Nanoajax.ajax
    this.canSave = true

    this.saving = on(this)

    if(enforcer != singletonEnforcer) throw "Cannot construct Json singleton"
  }

  static get instance() {
    if(!this[singleton]) {
      this[singleton] = new Json(singletonEnforcer)
      window.formJson = this[singleton]
    }
    return this[singleton]
  }

  save(type = 'draft') {
    this.saving._fire({type: type})
    var p = new Promise((resolve, reject) => {
      if(!this.canSave){
        resolve({})
        this.canSave = true
        return;
      }
      var jsonSave = this.data
      var abe_source = []

      if(typeof json.abe_source !== 'undefined' && json.abe_source !== null) {
        delete json.abe_source
      }

      var toSave = qs.stringify({
        tplPath: CONFIG.TPLPATH,
        filePath: CONFIG.FILEPATH,
        json: jsonSave,
        saveAction: type
      })

      this._ajax(
        {
          url: document.location.origin + '/save',
          body: toSave,
          method: 'post'
        },
        (code, responseText, request) => {
          var jsonRes = JSON.parse(responseText)
          if(typeof jsonRes.error !== 'undefined' && jsonRes.error !== null) {
            alert(jsonRes.error)
            return
          }
          if(typeof jsonRes.reject !== 'undefined' && jsonRes.reject !== null) {
            window.location.href = window.location.origin + window.location.pathname + '?filePath=' + jsonRes.reject
            return
          }
          this.data = jsonRes.json
          jsonRes.success = 1
          resolve(jsonRes)
        })
    })

    return p
  }

  set data(obj) {
    this._data = obj
  }

  get data() {
    return this._data
  }
}

==> abe-cli-0.4.1.tgz: package/src/server/public/scripts/modules/EditorJson.js <==
import Nanoajax from 'nanoajax'
import qs from 'qs'
import {Promise} from 'es6-promise'
import on from 'on'
let singleton = Symbol()
let singletonEnforcer = Symbol()

export default class Json {

  constructor(enforcer) {
    this._data = json
    this._ajax = Nanoajax.ajax
    this.canSave = true

    this.saving = on(this)

    if(enforcer != singletonEnforcer) throw "Cannot construct Json singleton"
  }

  static get instance() {
    if(!this[singleton]) {
      this[singleton] = new Json(singletonEnforcer)
      window.formJson = this[singleton]
    }
    return this[singleton]
  }

  save(type = 'draft') {
    this.saving._fire({type: type})
    var p = new Promise((resolve, reject) => {
      if(!this.canSave){
        resolve({})
        this.canSave = true
        return;
      }
      var jsonSave = this.data
      var abe_source = []

      if(typeof json.abe_source !== 'undefined' && json.abe_source !== null) {
        delete json.abe_source
      }

      var toSave = qs.stringify({
        tplPath: CONFIG.TPLPATH,
        filePath: CONFIG.FILEPATH,
        json: jsonSave
      })

      this._ajax(
        {
          url: document.location.origin + '/' + type,
          body: toSave,
          method: 'post'
        },
        (code, responseText, request) => {
          var jsonRes = JSON.parse(responseText)
          if(typeof jsonRes.error !== 'undefined' && jsonRes.error !== null) {
            alert(jsonRes.error)
            return
          }
          if(typeof jsonRes.reject !== 'undefined' && jsonRes.reject !== null) {
            window.location.href = window.location.origin + window.location.pathname + '?filePath=' + jsonRes.reject
            return
          }
          this.data = jsonRes.json
          // jsonRes.success = 1
          resolve(jsonRes)
        })
    })

    return p
  }

  set data(obj) {
    this._data = obj
  }

  get data() {
    return this._data
  }
}
